@@ -235,17 +235,29 @@ C<no Sys::Binmode>, thus:
 =item * C<do> and C<require>
 
 =item * File tests (e.g., C<-e>) and the following:
-C<chdir>, C<chmod>, C<chown>, C<chroot>,
+C<chdir>, C<chmod>, C<chown>, C<chroot>, C<ioctl>,
 C<link>, C<lstat>, C<mkdir>, C<open>, C<opendir>, C<readlink>, C<rename>,
 C<rmdir>, C<stat>, C<symlink>, C<sysopen>, C<truncate>,
 C<unlink>, C<utime>
 
-=item * C<bind>, C<connect>, and C<setsockopt>
+=item * C<bind>, C<connect>, C<setsockopt>, and C<send> (last argument)
 
 =item * C<syscall>
 
 =back
 
+=head2 Omissions
+
+=over
+
+=item * C<crypt> already does as Sys::Binmode would make it do.
+
+=item * C<select> (the 4-argument one) has the bug that Sys::Binmode fixes,
+but since it’s a performance-sensitive call where upgraded strings are
+unlikely, this library doesn’t wrap it.
+
+=back
+
 =head1 TODO
 
 =over
@@ -266,7 +278,7 @@ Maybe someday!
 
 #----------------------------------------------------------------------
 
-our $VERSION = '0.04_01';
+our $VERSION = '0.04_02';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
